/* The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 * 
 * The Original Code is Eric Hodel's <drbrain@segment7.net> code.
 * 
 * The Initial Developer of the Original Code is Eric Hodel.
 * Portions created by Eric Hodel are Copyright (C) 2001 Eric
 * Hodel. All Rights Reserved.
 * 
 * Other Contributors:
 *      Christopher Hoess <choess@force.stwing.upenn.edu>
 *      Tim Taylor <tim@tool-man.org>
 */

/** 
 * called on every page load 
 *
 * FIXME: refresh isn't called until the entire document has finished loading
 * XXX: optimization: don't refresh when page reloaded if the page hasn't
 *    been modified
 * XXX: optimization: don't refresh when toolbar is compacted
 */
function refresh() {
  if (!isLinkToolbarEnabled())
    return;

  profile("doRefresh", doRefresh);
}

function isLinkToolbarEnabled() {
  if (document.getElementById("cmd_viewlinktoolbar").getAttribute("checked") == "true")
    return true;
  else
    return false;
}

function doRefresh() {
  linkToolbarHandler.handleLinks(getLinkElements());
  linkToolbarHandler.handleLinks(getHttpEquivLinks());

  // FIXME: browser becomes unresponsive during this call...for as
  //    long as 2 or more seconds on heavily linked documents
  // linkToolbarHandler.handleLinks(getAnchorElements());
}

function getLinkElements() {
  return getHeadElement().getElementsByTagName("link");
}

function getHeadElement() {
  return window._content.document.getElementsByTagName("head").item(0);
}

function getHttpEquivLinks() {
  var links = new Array();
  var metas = getHeadElement().getElementsByTagName("meta");
  for (var i = 0; i < metas.length; i++) {
    if (metas.item(i).hasAttribute("http-equiv"))
      if (metas.item(i).getAttribute("http-equiv").toLowerCase() == "link")
        links.push(parseLinkHeader(metas.item(i).getAttribute("content")));
  }

  return new FakeNodeList(links);
}

function FakeNodeList(array) {
  this.array = array;
  this.length = array.length;

  this.item = function(i) {
    return array[i];
  }
}

function getAnchorElements() {
  // XXX: document.links includes AREA links, which technically 
  //    shouldn't be checked for REL attributes
  // FIXME: doesn't work on XHTML served as application/xhtml+xml
  return window._content.document.links;
}

/** called on every page unload */
function clear() {
  if (!isLinkToolbarEnabled())
    return;

  profile("doClear", doClear);
}

function doClear() {
  hideMiscellaneousSeperator();
  linkToolbarHandler.clearAllItems();
}

/** called whenever something on the toolbar is clicked */
function clicked(event) {
  if (event.target.nodeName == "menubutton") return;
  if (!event.target.getAttribute("href")) return;
  
  loadURI(event.target.getAttribute("href"));
}


// functions for twiddling XUL elements in the toolbar

function toggleLinkToolbar() {
  goToggleToolbar('linktoolbar', 'cmd_viewlinktoolbar');
  if (isLinkToolbarEnabled())
    profile("doRefresh", doRefresh);
  else
    profile("doClear", doClear);
}
function showMiscellaneousSeperator() {
  document.getElementById("misc-seperator").removeAttribute("collapsed");
}
function hideMiscellaneousSeperator() {
  document.getElementById("misc-seperator").setAttribute("collapsed", "true");
}
